powered by
Cpp_Clmbr
Internal S4 class.
Class of data + model objects used for broken line regression. An object instance stores pre-calculated quantities for a particular data set and model, so that methods can quickly compute exact-confidence intervals and regions for the changepoint.
Class "C++Object", directly.
"C++Object"
All reference classes extend and inherit methods from "envRefClass".
"envRefClass"
ci
printout confidence interval
cr
printout confidence region
mle
maximum likelihood estimates of parameters
sety
set new y-values in a Cpp_Clmbr object
sl
significance level for a postulate changepoint value
This class is internal, not meant for the user.
lm.br
showClass( Cpp_Clmbr )
Run the code above in your browser using DataLab